body {
	margin:0px;
	padding:0px;
	font-family:verdana, arial, helvetica, sans-serif;
	color:#333;
	background-color:white;
	}
h1 {
	margin:0px 0px 5px 0px;
	padding:0px;
	font-size:150%
	line-height:28px;
	font-weight:900;
	color:#ccc;
	}
h2 {
	font-size:125%;
	margin:0px;
	padding:5px 0px 10px 0px;
	}
h3 {
	font-size:110%;
	margin:0px;
	padding:5px 0px 10px 5px;
	}
h4 {
	font-size:100%;
	margin:0px;
	padding:5px 0px 10px 5px;
	}
h5 {
	font-size:100%;
	margin:0px;
	font-weight:600;
	padding:0px 0px 5px 0px;
	margin:0px 0px 0px 5px;
}
li {
	font:11px/20px verdana, arial, helvetica, sans-serif;
	margin:0px 0px 0px 10px;
	padding:0px;
	}
p {
	/* normal */
	font:11px/20px verdana, arial, helvetica, sans-serif;
	margin:0px 0px 0px 10px;
	padding:0px;
	}
        
tt {
	/* inline code */
	font-family: monospace;
	}
        
table {
        background-color:#efefef;
        /*background-color: white;*/
	border-style:solid;
	border-color:black;
	border-width:0px 1px 1px 0px;
        color: black;
        text-align: left;
	font:11px/20px verdana, arial, helvetica, sans-serif;
        margin-left: 5%;
        margin-right: 5%;
}

th {
	font-weight:500;
        background-color: #eaeaef;
        text-align: center;
}

td.header {
        font-weight: bold;
}
        
#Content>p {margin:0px;}
#Content>p+p {text-indent:30px;}
a {
	color:#09c;
	font-size:11px;
	text-decoration:none;
	font-weight:600;
	font-family:verdana, arial, helvetica, sans-serif;
	}
a:link {color:#09c;}
a:visited {color:#07a;}
a:hover {background-color:#eee;}

#Codeblock {
	margin:5px 50px 5px 10px;
	padding:5px 0px 5px 15px;
	border-style:solid;
	border-color:lightgrey;
	border-width:1px 1px 1px 1px;
	background-color:#f5f5ff;
	font-size:100%;
	font-weight:600;
	text-decoration:none;
	font-family:monospace;
}
#Interface {
	margin:5px 0px 25px 5px;
	padding:5px 0px 5px 5px;
	border-style:solid;
	border-color:black;
	border-width:1px 1px 1px 1px;
	background-color:#fafafa;
	font-size:14px;
	font-weight:400;
	text-decoration:none;
	font-family:verdana, arial, helvetica, sans-serif;
}
#Interfacesmall {
	margin:0px 0px 5px 0px;
	padding:5px 0px 0px 5px;
	border-style:solid;
	border-color:black;
	border-width:1px 1px 1px 1px;
	background-color:#fafafa;
	font-size:14px;
	font-weight:400;
	text-decoration:none;
	font-family:verdana, arial, helvetica, sans-serif;
}	
#Template {
	margin:5px 0px 25px 5px;
	padding:5px 0px 5px 5px;
	border-style:solid;
	border-color:black;
	border-width:1px 1px 1px 1px;
	background-color:#fafafa;
	font-size:14px;
	font-weight:400;
	text-decoration:none;
	font-family:verdana, arial, helvetica, sans-serif;
}
#Templatesmall {
	margin:0px 0px 5px 0px;
	padding:5px 0px 0px 5px;
	border-style:solid;
	border-color:black;
	border-width:1px 1px 1px 1px;
	background-color:#fafafa;
	font-size:14px;
	font-weight:400;
	text-decoration:none;
	font-family:verdana, arial, helvetica, sans-serif;
}	
#Description {
	margin:0px 0px 0px 5px;
	padding:0px 0px 0px 5px;
	text-decoration:none;
	font-family:verdana, arial, helvetica, sans-serif;
	font-size:12px;
	font-weight:400;
}
pre {
	margin:0px;
	padding:0px;
	font-size:14px;
	text-decoration:none;
	font-family:verdana, arial, helvetica, sans-serif;
}
dl {
	/* definition text block */
	font:11px/20px verdana, arial, helvetica, sans-serif;
	margin:0px 0px 16px 0px;
	padding:0px;
	}
dt {
	/* definition term */
        font-weight: bold;
	}

#Header {
	margin:50px 0px 10px 0px;
	padding:17px 0px 0px 20px;
	/* For IE5/Win's benefit height = [correct height] + [top padding] + [top and bottom border widths] */
	height:33px; /* 14px + 17px + 2px = 33px */
	border-style:solid;
	border-color:black;
	border-width:1px 0px; /* top and bottom borders: 1px; left and right borders: 0px */
	line-height:11px;
	font-size:110%;
	background-color:#eee;
	voice-family: "\"}\"";
	voice-family:inherit;
	height:14px; /* the correct height */
	}
body>#Header {height:14px;}
#Content {
	margin:0px 50px 0px 200px;
	padding:10px;
	}

#Menu {
	position:absolute;
	top:100px;
	left:20px;
	width:162px;
	padding:10px;
	background-color:#eee;
	border:1px solid #aaa;
	line-height:17px;
	text-align:left;	
	voice-family: "\"}\"";
	voice-family:inherit;
	width:160px;
	}
#Menu subitem {
	font-size: 5px;
}

body>#Menu {width:160px;}
